#
# spec file for package octave-forge-control
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define octpkg  control
Name:           octave-forge-%{octpkg}
Version:        3.0.0
Release:        lp152.3.9
Summary:        Computer-Aided Control System Design (CACSD) Tools
License:        GPL-3.0+
Group:          Productivity/Scientific/Math
Url:            http://octave.sourceforge.net
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM control-gcc-errors.patch -- Fix no return in non-void function
Patch1:         control-gcc-errors.patch
BuildRequires:  blas-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  octave-devel
Requires:       octave-cli >= 3.8.0

%description
Computer-Aided Control System Design (CACSD) Tools for GNU Octave, based
on the proven SLICOT Library.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%patch1 -p1
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Sat Oct 31 2015 dmitry_r@opensuse.org
- Update to version 3.0.0
  * Substantial parts of the most vital internals have been rewritten
    and streamlined in order to improve compatibility and reliability.
  * LTI models:
    Improved handling of key-value pairs in all constructors for LTI models.
    Support inheritance of LTI properties in many variations.
    Accept [] as an alias for unspecified sampling time (Ts = -1).
    Automatic vector expansion for input and output names.
  * dss
    Fixed a long-standing but undiscovered bug where 'dss (sys)'
    overwrites sys.e with an identity matrix even if sys.e was not empty.
  * ss
    Support for the special cases has been added.
  * tf, zpk, filt
    Restrict transfer function variable to the candidates 's', 'p' for
    continuous-time and 'z', 'q', 'z^-1', 'q^-1' for discrete-time models.
  * bode, bodemag, nichols, nyquist, sigma
    It is now possible to specify a frequency vector of length 1.
  * step, impulse, initial, ramp
    The time response functions now raise an error or warning if invalid
    arguments are passed to them.  As it was the case for frequency response
    functions, they used to simply ignore invalid arguments.
  * lsim
    Support logical arrays as input signal.  Before, logical arrays were
    simply ignored without notice, which could lead to unexpected results.
    Additionally, lsim received the same improvements as the other time and
    frequency response functions regarding invalid arguments.
  * pzmap
    Improved argument checks.
  * augstate
    New function for state-space models.  Adds the state vector to the output
    vector.
  * connect
    The function no longer raises an error for name-based interconnections
    if some systems have common input names and one of these inputs are to
    be kept.
  * estim
    Add input/output/state names to the returned system.  Support name-based
    selection of inputs (arguments 'sensors' and 'known').
  * * sumblk
    Add signal names as input/output groups if argument  n > 1.
  * * minreal
    If state-space models already have a minimal realization, then no state
    transformations are applied to the returned model.
* Sat Oct  3 2015 dmitry_r@opensuse.org
- Update to versiob 2.8.5
  * Bug fixes
  * Matlab compatibility improvements
* Wed Sep  9 2015 dmitry_r@opensuse.org
- Update to version 2.8.4
  * Bug fixes and minor changes
* Tue Jul  7 2015 dmitry_r@opensuse.org
- Update to version 2.8.3
  * Bug fixes and minor changes
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Update to version 2.8.2
  * Bugfix release
* Mon May  4 2015 dmitry_r@opensuse.org
- Update to version 2.8.1
  * tf
  - Revamped the modifications of TB01ZD from control version 2.8.0.
    The function now uses LAPACK routines to find the maximum norm element.
  - Improved error handling when converting state-space models.
* Tue Apr  7 2015 dmitry_r@opensuse.org
- Update to version 2.8.0
  * zero
    Compatibility fix in the C++ oct-file to support the upcoming Octave 4.0.
  * isminimumphase
    Reverted changes from control-2.6.6.  According to the
    definition of Byrnes/Isidori, the function tests whether the system
    has asymptotically stable zero dynamics. The poles are not tested.
  * series
    Fixed a bug which gave unnecessary error messages when the
    function is called with 4 arguments.
  * tf
    Resolved issues in MIMO state-space to transfer function
    conversion by implementing a more robust algorithm in SLICOT
    routine TB01ZD.
  * Support for 64bit indexing option.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.6.6
- Fix GCC errors: no return in non-void function
  * control-gcc-errors.patch
